#! /bin/sh

###########################################################################
#   @file       woroot-fixup.sh
#   @copyright  Copyright 2008 David F. Elliott <dfe@tgwbd.org>
#   @description
#   Installs the compatibility libraries built by the Xcode project and gently
#   modifies a few of the Apple-provided files.

pkg_name="WebObjectsLegacyDevelopment"
DSTROOT=/tmp/${pkg_name}.dst

if ! test -d build/Debug; then
	echo "Build directory not found" 1>&2
	exit 1
fi

if ! test -d "$DSTROOT"; then
	echo "DSTROOT (\"${DSTROOT}\") not found" 1>&2
	exit 1
fi

echo "---> Installing libraries"
mkdir -p "$DSTROOT/usr/local/lib"

for i in libSystemWOCompatibility.B.dylib libWOCompatibilityStreams.dylib libWOCompatibilityObjC.dylib; do
	cp -pv "build/Debug/$i"  "$DSTROOT/usr/local/lib/$i"
	chown root:wheel "$DSTROOT/usr/local/lib/$i"
done

cd "$DSTROOT"

echo "---> Patching binaries"
while read fn; do
	install_name_tool -change /usr/lib/libSystem.B.dylib /usr/local/lib/libSystemWOCompatibility.B.dylib "$fn"
done << EOF
Developer/Applications/WebObjects/EOModeler.app/Contents/MacOS/EOModeler
Developer/Applications/WebObjects/WebObjects Builder.app/Contents/MacOS/WebObjects Builder
System/Library/PrivateFrameworks/WODevKit.framework/Versions/C/WODevKit
EOF

echo "---> Patching WOJavaPBXHelper's Info.plist"
WOJavaPBXHelper_Info="${DSTROOT}/Developer/Library/Xcode/Plug-ins/WOJavaPBXHelper.pbplugin/Contents/Info"
# Add the XCGCReady key with the value YES (NOTE: defaults cannot accept the .plist extension)"
defaults write "${WOJavaPBXHelper_Info}" XCGCReady YES
# Convert it back to an XML plist
plutil -convert xml1 "${WOJavaPBXHelper_Info}.plist"
# Fixup the mode (defaults changes it to 600)
chmod 644 "${WOJavaPBXHelper_Info}.plist"
# NOTE: This slightly changes the DTD ("Apple Computer" changes to "Apple" on Leopard systems)
# NOTE: WOAssistant might work (with this plist hack) but EOPlaceholders is missing from the Xcode 2.5 package.
# NOTE: XDEOModelPlugin is not compiled for GC.  No chance of working.  We still install it though.

